=============================
 Invenio-OAuth2Server v0.1.1
=============================

Invenio-OAuth2Server v0.1.1 was released on August 25, 2015.

About
-----

Invenio module that implements OAuth 2 server.

*This is an experimental development preview release.*

Improved features
-----------------

- Marks strings in templates for translations.  (#3)

Bug fixes
---------

- Adds missing `invenio_upgrader` dependency and amends past upgrade
  recipes following its separation into standalone package.

Installation
------------

   $ pip install invenio-oauth2server==0.1.1

Documentation
-------------

   http://invenio-oauth2server.readthedocs.org/en/v0.1.1

Happy hacking and thanks for flying Invenio-OAuth2Server.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-oauth2server
|   URL: http://invenio-software.org
